#ifndef SRC_MULTI_BODY_PROBLEM_DATA_WEAKPATCH_HH
#define SRC_MULTI_BODY_PROBLEM_DATA_WEAKPATCH_HH

#include <dune/common/parametertree.hh>

#include <dune/fufem/geometry/convexpolyhedron.hh>

#include "grid/cuboidgeometry.hh"

template <class LocalVector>
void getWeakPatch(Dune::ParameterTree const &parset, CuboidGeometry const &cuboidGeometry, ConvexPolyhedron<LocalVector>& lowerWeakPatch, ConvexPolyhedron<LocalVector>& upperWeakPatch) {

#if MY_DIM == 3
  if (cuboidGeometry.V != cuboidGeometry.W) {
    lowerWeakPatch.vertices.resize(4);
    lowerWeakPatch.vertices[0] = lowerWeakPatch.vertices[2] = cuboidGeometry.V;
    lowerWeakPatch.vertices[1] = lowerWeakPatch.vertices[3] = cuboidGeometry.W;
    for (size_t k = 0; k < 2; ++k) {
        lowerWeakPatch.vertices[k][2] = -cuboidGeometry.depth / 2.0;
        lowerWeakPatch.vertices[k + 2][2] = cuboidGeometry.depth / 2.0;
    }
    switch (parset.get<Config::PatchType>("patchType")) {
        case Config::Rectangular:
            break;
        case Config::Trapezoidal:
            lowerWeakPatch.vertices[1][0] += 0.05 * cuboidGeometry.lengthScale;
            lowerWeakPatch.vertices[3][0] -= 0.05 * cuboidGeometry.lengthScale;
            break;
        default:
            assert(false);
    }
  }

  if (cuboidGeometry.X != cuboidGeometry.Y) {
    upperWeakPatch.vertices.resize(4);
    upperWeakPatch.vertices[0] = upperWeakPatch.vertices[2] = cuboidGeometry.X;
    upperWeakPatch.vertices[1] = upperWeakPatch.vertices[3] = cuboidGeometry.Y;
    for (size_t k = 0; k < 2; ++k) {
        upperWeakPatch.vertices[k][2] = -cuboidGeometry.depth / 2.0;
        upperWeakPatch.vertices[k + 2][2] = cuboidGeometry.depth / 2.0;
    }
    switch (parset.get<Config::PatchType>("patchType")) {
        case Config::Rectangular:
            break;
        case Config::Trapezoidal:
            upperWeakPatch.vertices[1][0] += 0.05 * cuboidGeometry.lengthScale;
            upperWeakPatch.vertices[3][0] -= 0.05 * cuboidGeometry.lengthScale;
            break;
        default:
            assert(false);
    }
  }
#else
  if (cuboidGeometry.V != cuboidGeometry.W) {
    lowerWeakPatch.vertices.resize(2);
    lowerWeakPatch.vertices[0] = cuboidGeometry.V;
    lowerWeakPatch.vertices[1] = cuboidGeometry.W;
  }

  if (cuboidGeometry.X != cuboidGeometry.Y) {
    upperWeakPatch.vertices.resize(2);
    upperWeakPatch.vertices[0] = cuboidGeometry.X;
    upperWeakPatch.vertices[1] = cuboidGeometry.Y;
  }
#endif
};
#endif
